@@ -8,7 +8,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-27'; # DATE
 our $DIST = 'Text-Table-More'; # DIST
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 # see Module::Features for more details on this
 our %FEATURES = (
@@ -17,6 +17,19 @@ our %FEATURES = (
     },
 
     features => {
+        PerlTrove => {
+            "Development Status" => "4 - Beta",
+            "Environment" => "Console",
+            # Framework
+            "Intended Audience" => ["Developers"],
+            "License" => "OSI Approved :: Artistic License",
+            # Natural Language
+            # Operating System
+            "Programming Language" => "Perl",
+            "Topic" => ["Software Development :: Libraries :: Perl Modules", "Utilities"],
+            # Typing
+        },
+
         TextTable => {
             can_align_cell_containing_wide_character => 1,
             can_align_cell_containing_color_code     => 1,
@@ -608,7 +621,7 @@ Text::Table::More - Generate text table with simple interface and many options
 
 =head1 VERSION
 
-This document describes version 0.017 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-27.
+This document describes version 0.018 of Text::Table::More (from Perl distribution Text-Table-More), released on 2021-08-27.
 
 =head1 SYNOPSIS
 
@@ -755,6 +768,38 @@ Keywords: rowspan, colspan.
 
 Features declared by this module:
 
+=head2 From feature set PerlTrove
+
+Features from feature set L<PerlTrove|Module::Features::PerlTrove> declared by this module:
+
+=over
+
+=item * Development Status
+
+Value: "4 - Beta".
+
+=item * Environment
+
+Value: "Console".
+
+=item * Intended Audience
+
+Value: ["Developers"].
+
+=item * License
+
+Value: "OSI Approved :: Artistic License".
+
+=item * Programming Language
+
+Value: "Perl".
+
+=item * Topic
+
+Value: ["Software Development :: Libraries :: Perl Modules","Utilities"].
+
+=back
+
 =head2 From feature set TextTable
 
 Features from feature set L<TextTable|Module::Features::TextTable> declared by this module:
